@@ -50,12 +50,16 @@
 package com.openexchange.imageconverter.client;
 
 import java.net.HttpURLConnection;
+
 import javax.net.ssl.HttpsURLConnection;
 import javax.net.ssl.SSLContext;
 import javax.net.ssl.SSLSocketFactory;
+
 import org.glassfish.jersey.client.HttpUrlConnectorProvider;
+
 import com.openexchange.annotation.NonNull;
 import com.openexchange.annotation.Nullable;
+import com.openexchange.auth.Credentials;
 import com.openexchange.imageconverter.client.generated.invoker.ApiClient;
 import com.openexchange.imageconverter.client.generated.modules.ImageConverterApi;
 
@@ -80,14 +84,6 @@ class ImageConverterApiProvider {
         m_apiClient = null;
     }
 
-    /**
-     * Initializes a new {@link ImageConverterApiProvider}.
-     * @param imageConverterClientConfig
-     */
-    ImageConverterApiProvider(@NonNull final ImageConverterClientConfig imageConverterClientConfig) {
-        this(imageConverterClientConfig, null, null);
-    }
-
     /**
      * Initializes a new {@link ImageConverterAPIProvider}.
      * @param imageConverterRemoteValidator
@@ -124,16 +120,27 @@ class ImageConverterApiProvider {
                         clientBuilder;
             });
 
-        m_apiClient.setBasePath(imageConverterClientConfig.getImageConverterServerURL().toString());
-        m_apiClient.setTempFolderPath(imageConverterClientConfig.getSpoolDir().getAbsolutePath());
-        m_apiClient.setConnectTimeout(DEFAULT_CONNECT_TIMEOUT_MILLIS);
+       implConfigure(imageConverterClientConfig);
     }
 
     /**
      * @return
      */
     ImageConverterApi acquire() {
-        return new ImageConverterApi(m_apiClient);
+        final ApiClient apiClient = m_apiClient;
+
+        if (null != apiClient) {
+            final Credentials credentials = m_credentials;
+
+            if (null != credentials) {
+                apiClient.setUsername(credentials.getLogin());
+                apiClient.setPassword(credentials.getPassword());
+            }
+
+            return new ImageConverterApi(m_apiClient);
+        }
+
+        return null;
     }
 
     /**
@@ -143,7 +150,36 @@ class ImageConverterApiProvider {
         // nothing to be done here
     }
 
+    /**
+     * @param imageConverterClientConfig
+     */
+    public void updateConfiguration(@NonNull final ImageConverterClientConfig imageConverterClientConfig) {
+        implConfigure(imageConverterClientConfig);
+    }
+
+    /**
+     * @param credentials
+     */
+    public void setCredentials(@NonNull final Credentials credentials) {
+        m_credentials = credentials;
+    }
+
+    // - Implementation --------------------------------------------------------
+
+    private void implConfigure(@NonNull final ImageConverterClientConfig imageConverterClientConfig) {
+        final ApiClient apiClient = m_apiClient;
+
+        if (null != apiClient) {
+            apiClient.setBasePath(imageConverterClientConfig.getImageConverterServerURL().toString());
+            apiClient.setTempFolderPath(imageConverterClientConfig.getSpoolDir().getAbsolutePath());
+            apiClient.setConnectTimeout(DEFAULT_CONNECT_TIMEOUT_MILLIS);
+        }
+    }
+
+
     // - Members ---------------------------------------------------------------
 
-    final private ApiClient m_apiClient;
+    volatile private ApiClient m_apiClient;
+
+    volatile private Credentials m_credentials;
 }
