@@ -49,8 +49,10 @@
 
 package com.openexchange.imageconverter.client;
 
-import static org.apache.commons.lang.ArrayUtils.isNotEmpty;
+import static org.apache.commons.lang.ArrayUtils.isEmpty;
+import static org.apache.commons.lang.StringUtils.isEmpty;
 import static org.apache.commons.lang.StringUtils.isNotEmpty;
+
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
 import java.io.File;
@@ -58,9 +60,11 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.util.List;
 import java.util.Map;
+
 import javax.net.ssl.SSLContext;
 import javax.net.ssl.SSLSocketFactory;
 import javax.ws.rs.core.Response.Status;
+
 import org.apache.commons.fileupload.MultipartStream;
 import org.apache.commons.io.FileUtils;
 import org.apache.commons.io.IOUtils;
@@ -68,10 +72,13 @@ import org.apache.commons.lang.StringUtils;
 import org.json.JSONObject;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
+
 import com.google.common.base.Throwables;
 import com.openexchange.annotation.NonNull;
 import com.openexchange.annotation.Nullable;
+import com.openexchange.auth.Credentials;
 import com.openexchange.config.ConfigurationService;
+import com.openexchange.config.Interests;
 import com.openexchange.exception.OXException;
 import com.openexchange.imageconverter.api.IImageClient;
 import com.openexchange.imageconverter.api.IMetadata;
@@ -105,6 +112,7 @@ public class ImageConverterClient implements IImageClient {
 
     /**
      * Initializes a new {@link ImageConverterClient}.
+     *
      * @param imageConverterClientConfig
      * @throws OXException
      */
@@ -118,7 +126,7 @@ public class ImageConverterClient implements IImageClient {
         m_clientConfig = new ImageConverterClientConfig(configurationService);
 
         if (!m_clientConfig.isValid()) {
-        	throw OXException.general("Configuration service is available, but config property is not valid");
+            throw OXException.general("Configuration service is available, but config property is not valid");
         }
 
         m_apiProvider = new ImageConverterApiProvider(m_clientConfig, sslSocketFactory, sslContext);
@@ -126,6 +134,31 @@ public class ImageConverterClient implements IImageClient {
     }
 
     /* (non-Javadoc)
+     * @see com.openexchange.config.Reloadable#reloadConfiguration(com.openexchange.config.ConfigurationService)
+     */
+    @Override
+    public void reloadConfiguration(ConfigurationService configService) {
+        if (null != m_clientConfig) {
+            m_clientConfig.reloadConfiguration(configService);
+
+            m_apiProvider.updateConfiguration(m_clientConfig);
+            m_remoteValidator.updateRemoteURL(m_clientConfig.getImageConverterServerURL());
+        }
+    }
+
+    /* (non-Javadoc)
+     * @see com.openexchange.config.Reloadable#getInterests()
+     */
+    @Override
+    public Interests getInterests() {
+        return (null != m_clientConfig) ?
+            m_clientConfig.getInterests() :
+                null;
+    }
+
+    /*
+     * (non-Javadoc)
+     *
      * @see java.io.Closeable#close()
      */
     @Override
@@ -133,7 +166,9 @@ public class ImageConverterClient implements IImageClient {
         m_clientConfig.shutdown();
     }
 
-    /* (non-Javadoc)
+    /*
+     * (non-Javadoc)
+     *
      * @see com.openexchange.imageconverter.api.IImageConverter#getImage(java.lang.String, java.lang.String, java.lang.String)
      */
     @Override
@@ -168,7 +203,9 @@ public class ImageConverterClient implements IImageClient {
         return ret;
     }
 
-    /* (non-Javadoc)
+    /*
+     * (non-Javadoc)
+     *
      * @see com.openexchange.imageconverter.api.IImageConverter#getMetadata(java.lang.String, java.lang.String[])
      */
     @Override
@@ -211,7 +248,9 @@ public class ImageConverterClient implements IImageClient {
         return ret;
     }
 
-    /* (non-Javadoc)
+    /*
+     * (non-Javadoc)
+     *
      * @see com.openexchange.imageconverter.api.IImageConverter#getImageAndMetadata(java.lang.String, java.lang.String, java.lang.String[])
      */
     @Override
@@ -250,7 +289,9 @@ public class ImageConverterClient implements IImageClient {
         return ret;
     }
 
-    /* (non-Javadoc)
+    /*
+     * (non-Javadoc)
+     *
      * @see com.openexchange.imageconverter.api.IImageConverter#cacheImage(java.lang.String, java.lang.String, java.io.InputStream)
      */
     @Override
@@ -273,7 +314,7 @@ public class ImageConverterClient implements IImageClient {
                             FileUtils.deleteQuietly(tmpInputFile);
                         }
                     } else if (LOG.isWarnEnabled()) {
-                        LOG.warn("InputStream in call to ImageConverter#cacheImage is empty (imageKey): " + imageKey);
+                        LOG.warn("InputStream in call to ImageConverter#cacheImage is empty (imageKey): {}", imageKey);
                     }
                 }
             } finally {
@@ -282,7 +323,9 @@ public class ImageConverterClient implements IImageClient {
         }
     }
 
-    /* (non-Javadoc)
+    /*
+     * (non-Javadoc)
+     *
      * @see com.openexchange.imageconverter.api.IImageConverter#cacheAndGetImage(java.lang.String, java.lang.String, java.lang.String, java.io.InputStream)
      */
     @Override
@@ -314,7 +357,7 @@ public class ImageConverterClient implements IImageClient {
                                 FileUtils.deleteQuietly(tmpResponseFile);
                             }
                         } else if (LOG.isWarnEnabled()) {
-                            LOG.warn("InputStream in call to ImageConverter#cacheAndGetImage is empty (imageKey): " + imageKey);
+                            LOG.warn("InputStream in call to ImageConverter#cacheAndGetImage is empty (imageKey): {}", imageKey);
                         }
                     } else {
                         ret = getImage(imageKey, requestFormat, context);
@@ -328,7 +371,9 @@ public class ImageConverterClient implements IImageClient {
         return ret;
     }
 
-    /* (non-Javadoc)
+    /*
+     * (non-Javadoc)
+     *
      * @see com.openexchange.imageconverter.api.IImageConverter#cacheAndGetImageAndMetadata(java.lang.String, java.lang.String, java.io.InputStream, java.lang.String[])
      */
     @Override
@@ -364,7 +409,7 @@ public class ImageConverterClient implements IImageClient {
                                 FileUtils.deleteQuietly(tmpResponseFile);
                             }
                         } else if (LOG.isWarnEnabled()) {
-                            LOG.warn("InputStream in call to ImageConverter#cacheAndGetImageAndMetadata is empty (imageKey): " + imageKey);
+                            LOG.warn("InputStream in call to ImageConverter#cacheAndGetImageAndMetadata is empty (imageKey): {}", imageKey);
                         }
                     }
                 }
@@ -376,7 +421,9 @@ public class ImageConverterClient implements IImageClient {
         return ret;
     }
 
-    /* (non-Javadoc)
+    /*
+     * (non-Javadoc)
+     *
      * @see com.openexchange.imageconverter.api.IImageConverter#clearImagesByContext(java.lang.String)
      */
     @Override
@@ -396,7 +443,9 @@ public class ImageConverterClient implements IImageClient {
         }
     }
 
-    /* (non-Javadoc)
+    /*
+     * (non-Javadoc)
+     *
      * @see com.openexchange.imageconverter.api.IImageConverter#clearImagesByKey(java.lang.String)
      */
 
@@ -417,7 +466,9 @@ public class ImageConverterClient implements IImageClient {
         }
     }
 
-    /* (non-Javadoc)
+    /*
+     * (non-Javadoc)
+     *
      * @see com.openexchange.imageconverter.api.IImageConverter#getKeyCountByContext(java.lang.String)
      */
     @Override
@@ -440,13 +491,15 @@ public class ImageConverterClient implements IImageClient {
         return ret;
     }
 
-    /* (non-Javadoc)
+    /*
+     * (non-Javadoc)
+     *
      * @see com.openexchange.imageconverter.api.IImageConverter#getKeys()
      */
     @Override
     public String[] getKeys(final String... context) throws ImageConverterException {
         final ImageConverterApi api = m_apiProvider.acquire();
-        String [] ret = {};
+        String[] ret = {};
 
         LOG.trace("IC client #getKeys called");
 
@@ -464,7 +517,9 @@ public class ImageConverterClient implements IImageClient {
         return ret;
     }
 
-    /* (non-Javadoc)
+    /*
+     * (non-Javadoc)
+     *
      * @see com.openexchange.imageconverter.api.IImageConverter#getTotalImagesSize(java.lang.String[])
      */
     @Override
@@ -473,7 +528,9 @@ public class ImageConverterClient implements IImageClient {
         return 0;
     }
 
-    /* (non-Javadoc)
+    /*
+     * (non-Javadoc)
+     *
      * @see com.openexchange.imageconverter.api.IImageClient#status()
      */
     @Override
@@ -489,7 +546,7 @@ public class ImageConverterClient implements IImageClient {
             } catch (ApiException e) {
                 ImageConverterException ice = implWrapAPIException("Error in remote calling ImageConverter#status", e);
                 if (ice != null) {
-                	throw OXException.general(ice.getMessage(), ice);
+                    throw OXException.general(ice.getMessage(), ice);
                 }
             } finally {
                 m_apiProvider.release(api);
@@ -499,14 +556,26 @@ public class ImageConverterClient implements IImageClient {
         return ret;
     }
 
-    /* (non-Javadoc)
+    /*
+     * (non-Javadoc)
+     *
      * @see com.openexchange.imageconverter.api.IImageClient#isConnected()
      */
     @Override
-    public boolean isConnected() throws OXException {
+    public boolean isConnected() {
         return m_remoteValidator.isConnected();
     }
 
+    /**
+     *
+     */
+    @Override
+    public void setCredentials(Credentials credentials) {
+        if (null != credentials) {
+            m_apiProvider.setCredentials(credentials);
+        }
+    }
+
     // - public interface ------------------------------------------------------
 
     /**
@@ -519,10 +588,10 @@ public class ImageConverterClient implements IImageClient {
     // - Implementation --------------------------------------------------------
 
     private void implHandleAPIException(final String msg, final ApiException e) throws ImageConverterException {
-    	final ImageConverterException ice = implWrapAPIException(msg, e);
-    	if (ice != null) {
-    		throw ice;
-    	}
+        final ImageConverterException ice = implWrapAPIException(msg, e);
+        if (ice != null) {
+            throw ice;
+        }
     }
 
     private ImageConverterException implWrapAPIException(final String msg, final ApiException e) {
@@ -532,7 +601,7 @@ public class ImageConverterClient implements IImageClient {
         if (null != e) {
             final Throwable cause = Throwables.getRootCause(e);
             final String causeMessage = (null != cause) ? cause.getMessage() : null;
-            final int  statusCode = e.getCode();
+            final int statusCode = e.getCode();
 
             if (Status.NOT_FOUND.getStatusCode() == statusCode) {
                 throwException = false;
@@ -540,7 +609,7 @@ public class ImageConverterClient implements IImageClient {
                 LOG.trace("IC client received a resource NOT_FOUND error from server => proceeding normally");
             } else {
                 if ((e.getCode() == 503) || (cause instanceof IOException) || StringUtils.containsIgnoreCase(causeMessage, "terminated")) {
-                    m_remoteValidator.resetConnection();
+                    m_remoteValidator.connectionLost();
 
                     LOG.warn(new StringBuilder("IC client lost remote connection (cause: ").
                         append(StringUtils.isBlank(causeMessage) ? "n/a" : causeMessage).
@@ -563,9 +632,7 @@ public class ImageConverterClient implements IImageClient {
      * @return
      */
     private static String implGetContext(final String... context) {
-        return ((isNotEmpty(context) && isNotEmpty(context[0])) ?
-            context[0] :
-                null);
+        return ((isEmpty(context) || isEmpty(context[0])) ? null : context[0]);
     }
 
     /**
@@ -635,9 +702,9 @@ public class ImageConverterClient implements IImageClient {
                             }
                         }
                     }
-                 } while (multipartStream.readBoundary());
+                } while (multipartStream.readBoundary());
 
-                 ret = new MetadataImage(imageInputStm, metadata);
+                ret = new MetadataImage(imageInputStm, metadata);
             }
         }
 
@@ -646,17 +713,10 @@ public class ImageConverterClient implements IImageClient {
 
     // -- Statics --------------------------------------------------------------
 
-    /**
-     * @return
-     */
-    public static Logger getLogger() {
-        return LOG;
-    }
+    final static Logger LOG = LoggerFactory.getLogger(ImageConverterClient.class);
 
     // - Members ---------------------------------------------------------------
 
-    final protected static Logger LOG = LoggerFactory.getLogger(ImageConverterClient.class);
-
     final private ImageConverterClientConfig m_clientConfig;
 
     final private ImageConverterRemoteValidator m_remoteValidator;
