@@ -52,8 +52,10 @@ package com.openexchange.imageconverter.client.osgi;
 import org.apache.commons.io.IOUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
+
 import com.google.common.base.Throwables;
 import com.openexchange.config.ConfigurationService;
+import com.openexchange.config.Reloadable;
 import com.openexchange.exception.OXException;
 import com.openexchange.imageconverter.api.IImageClient;
 import com.openexchange.imageconverter.api.IMetadataReader;
@@ -104,7 +106,7 @@ public class ImageConverterClientActivator extends HousekeepingActivator {
      */
     @Override
     public void startBundle() throws Exception {
-        LOG.info("starting bundle: " + SERVICE_NAME);
+        LOG.info("starting bundle: {}", SERVICE_NAME);
 
         Services.setServiceLookup(this);
 
@@ -123,16 +125,21 @@ public class ImageConverterClientActivator extends HousekeepingActivator {
                 throw new OXException(new Throwable("SSLSocketFactoryProvider service not available"));
             }
 
+            // register IImageClient service
             registerService(IImageClient.class, m_imageConverterClient = new ImageConverterClient(
                 configService,
                 sslSocketFactoryProvider.getOriginatingDefaultContext(),
                 sslSocketFactoryProvider.getDefault()));
 
+            // register IImageClient service as Reloadable configuration
+            // service for changing the remote URL config item at runtime
+            registerService(Reloadable.class, m_imageConverterClient);
+
             openTrackers();
 
-            LOG.info("Successfully started bundle: " + SERVICE_NAME);
+            LOG.info("Successfully started bundle: {}", SERVICE_NAME);
         } catch (Throwable e) {
-            LOG.error("... starting bundle: " + SERVICE_NAME + " failed", Throwables.getRootCause(e));
+            LOG.error("... starting bundle {} failed: {}", SERVICE_NAME, Throwables.getRootCause(e));
             throw new RuntimeException(e);
         }
     }
@@ -144,7 +151,7 @@ public class ImageConverterClientActivator extends HousekeepingActivator {
      */
     @Override
     public void stopBundle() throws Exception {
-        LOG.info("stopping bundle: " + SERVICE_NAME);
+        LOG.info("stopping bundle: {}", SERVICE_NAME);
 
         closeTrackers();
         unregisterServices();
@@ -153,7 +160,7 @@ public class ImageConverterClientActivator extends HousekeepingActivator {
         IOUtils.closeQuietly(m_imageConverterClient);
         m_imageConverterClient = null;
 
-        LOG.info("successfully stopped bundle: " + SERVICE_NAME);
+        LOG.info("successfully stopped bundle: {}", SERVICE_NAME);
     }
 
     // - Members ---------------------------------------------------------------
